vrip_param -quiet 1

set vripDir $env(VRIP_DIR)

set gridFile [lindex $argv 0]
set plyFile [lindex $argv 1]

set fillHoles 0
set filterHoles 0
set removeSlivers 0

if {$argc > 2} {
    for {set i 2} {$i < $argc} {incr i} {
        set arg [lindex $argv $i]
        if {$arg == "-fill_holes"} {
	    set fillHoles 1
        } elseif {$arg == "-remove_slivers"} {
	    set removeSlivers 1
        } elseif {$arg == "-filter_holes"} {
	    set filterHoles 1
        }
    }
}

if {$fillHoles} {
    puts "Preparing for marching cubes"
    readgrid $gridFile
    vrip_varfromconst

    set i 0
    while {1} {
	set tempFileName /usr/tmp/temp_$i.occ
	if {![file exists $tempFileName]} {
	    break
	}
	incr i
    }
    puts "Creating $tempFileName..."
    flush stdout
    writegrid $tempFileName
    exec chmod +w $tempFileName

    puts "Generating polygons with marching cubes..."
    flush stdout
    exec vripmarch $tempFileName $plyFile -1 2> /dev/null

    puts "Removing $tempFileName..."
    flush stdout
    exec rm $tempFileName 2> /dev/null

    puts "Extracting largest connected component..."
    flush stdout
    exec plycomps -m 1 $plyFile -t 1 < $plyFile 2> /dev/null

} else {
    puts "Generating polygons with marching cubes..."
    flush stdout
    exec vripmarch $gridFile $plyFile 2> /dev/null
}

if {$removeSlivers} {
    catch {exec vriphead $gridFile} msg
    set x [string last Resolution: $msg]
    set x [expr $x + [string length Resolution:] + 1]
    set resolution [string range $msg $x end]
    set edgeLength [expr $resolution * 0.6]
    puts "Removing sliver triangles..."
    flush stdout
    exec triedgecol $plyFile $plyFile $edgeLength 150
    exec trisliver $plyFile $plyFile 150
}

if {$filterHoles} {
    exec trifilt $plyFile $plyFile \
	    -iters 50 -alpha 0.67 -lambda -0.63 -minconf 0.025 -confsteps 8
}

puts "Generating multi-res..."
flush stdout
exec ${vripDir}/crunch.csh $plyFile 2>/dev/null
exit

